@@ -4,21 +4,20 @@ from __future__ import print_function, absolute_import, division, unicode_litera
 
 _package_data = dict(
     full_package_name='ruamel.std.pathlib',
-    version_info=(0, 6, 2),
-    __version__='0.6.2',
+    version_info=(0, 6, 4),
+    __version__='0.6.4',
     author='Anthon van der Neut',
     author_email='a.van.der.neut@ruamel.eu',
     since=2013,
     description='improvements over the standard pathlib module and pathlib2 package',
     entry_points=None,
     extras_require={
-        'python_version<="3.4"': ['pathlib2', ],
+        ':python_version<="3.4"': ['pathlib2', ],
     },
     license='MIT License',
     universal=True,
     tox=dict(
         env='*',
-        deps='pathlib2',
     ),
 )
 # pathlib2 for 3.4 -> expanduser added
@@ -124,6 +123,15 @@ def _copy(self, target):
 Path.copy = _copy
 
 
+# this is the times parameter of os.utime, taking int/float seconds (and not nanoseconds)
+def _utime(self, atime, mtime):
+    os.utime(str(self), (atime, mtime), follow_symlinks=False)
+
+
+Path.utime = _utime
+
+
+
 # #
 # # - If the check level is set at 1, any calls that are issued with strings that
 # #     could be changed are logged (to the console), those are the positions where
